@@ -2,18 +2,23 @@
 //
 // ksprite - QCanvas based screensaver
 //
-// Copyright (c)  Martin R. Jones 1996
+// Copyright Martin R. Jones 1996 <mjones@kde.org>
 //
 
 #ifndef __SPRITE_H__
 #define __SPRITE_H__
 
-#include <qtimer.h>
-#include <qpushbutton.h>
-#include <qptrlist.h>
-#include <qstrlist.h>
-#include <qcanvas.h>
+#include <QtCore/QTimer>
+#include <QtGui/QPushButton>
+#include <Qt3Support/Q3PtrList>
+#include <Qt3Support/Q3StrList>
+#include <Qt3Support/Q3Canvas>
+#include <QtCore/QTimerEvent>
+#include <QtCore/QVector>
+#include <QtGui/QDialog>
+
 #include <kscreensaver.h>
+
 #include "spriteanim.h"
 
 //-----------------------------------------------------------------------------
@@ -21,7 +26,7 @@ class KSpriteSaver : public KScreenSaver
 {
 	Q_OBJECT
 public:
-    KSpriteSaver( WId id );
+    explicit KSpriteSaver( WId id );
     virtual ~KSpriteSaver();
 
     void setSpeed(int speed);
@@ -38,19 +43,19 @@ protected:
     virtual void timerEvent(QTimerEvent *);
 
 protected:
-    QCanvas	*mCanvas;
-    QCanvasView	*mView;
+    Q3Canvas	*mCanvas;
+    Q3CanvasView	*mView;
     QTimer	mTimer;
     int                 mSpeed;
-    QPtrList<SpriteGroup>  mGroups;
-    QMemArray<int>    mTimerIds;
+    QList<SpriteGroup*>  mGroups;
+    QVector<int>    mTimerIds;
 };
 
 class KSpriteSetup : public QDialog
 {
     Q_OBJECT
 public:
-    KSpriteSetup( QWidget *parent = NULL, const char *name = NULL );
+    explicit KSpriteSetup( QWidget *parent = NULL, const char *name = NULL );
     ~KSpriteSetup();
 
 protected:
