@@ -173,7 +173,7 @@ void ServiceConfigWidget::loadLocations()
   QStringList regions = group.readEntry("regions").split( ' ');
 
   QStringList::ConstIterator regionIt;
-  for ( regionIt = regions.begin(); regionIt != regions.end(); ++regionIt ) {
+  for ( regionIt = regions.constBegin(); regionIt != regions.constEnd(); ++regionIt ) {
     group = config.group(*regionIt);
     QString name = group.readEntry( "name" );
     QStringList states = group.readEntry( "states" ).split( ' ' );
@@ -182,7 +182,7 @@ void ServiceConfigWidget::loadLocations()
     regionItem->setSelectable( false );
 
     QStringList::ConstIterator stateIt;
-    for ( stateIt = states.begin(); stateIt != states.end(); ++stateIt ) {
+    for ( stateIt = states.constBegin(); stateIt != states.constEnd(); ++stateIt ) {
       group = config.group(*regionIt + '_' + *stateIt );
       QString name = group.readEntry( "name" );
 
@@ -191,7 +191,7 @@ void ServiceConfigWidget::loadLocations()
 
       QMap<QString, QString> entries = group.entryMap( );
       QMap<QString, QString>::ConstIterator entryIt;
-      for ( entryIt = entries.begin(); entryIt != entries.end(); ++entryIt ) {
+      for ( entryIt = entries.constBegin(); entryIt != entries.constEnd(); ++entryIt ) {
         if ( entryIt.key() != "name" ) {
           QString station, uid;
           // get station and uid from the data
